@@ -1,7 +1,9 @@
 package App::lcpan::Cmd::mentions_for_all_mods;
 
-our $DATE = '2021-06-03'; # DATE
-our $VERSION = '1.067'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-06-05'; # DATE
+our $DIST = 'App-lcpan'; # DIST
+our $VERSION = '1.068'; # VERSION
 
 use 5.010;
 use strict;
@@ -18,6 +20,13 @@ my $mentions_for_mod_args = $App::lcpan::Cmd::mentions_for_mod::SPEC{handle_cmd}
 $SPEC{'handle_cmd'} = {
     v => 1.1,
     summary => 'List PODs which mention all specified module(s)',
+    description => <<'_',
+
+This subcommand searches PODs that mention all of the specified modules. To
+search for PODs that mention *any* of the specified modules, see the
+`mentions-for-mods` subcommand.
+
+_
     args => $mentions_for_mod_args,
 };
 sub handle_cmd {
@@ -65,7 +74,7 @@ App::lcpan::Cmd::mentions_for_all_mods - List PODs which mention all specified m
 
 =head1 VERSION
 
-This document describes version 1.067 of App::lcpan::Cmd::mentions_for_all_mods (from Perl distribution App-lcpan), released on 2021-06-03.
+This document describes version 1.068 of App::lcpan::Cmd::mentions_for_all_mods (from Perl distribution App-lcpan), released on 2021-06-05.
 
 =head1 FUNCTIONS
 
@@ -78,6 +87,10 @@ Usage:
 
 List PODs which mention all specified module(s).
 
+This subcommand searches PODs that mention all of the specified modules. To
+search for PODs that mention I<any> of the specified modules, see the
+C<mentions-for-mods> subcommand.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
