@@ -1,7 +1,9 @@
 package App::lcpan::Cmd::mentions_for_mod;
 
-our $DATE = '2021-06-03'; # DATE
-our $VERSION = '1.067'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-06-05'; # DATE
+our $DIST = 'App-lcpan'; # DIST
+our $VERSION = '1.068'; # VERSION
 
 use 5.010;
 use strict;
@@ -22,7 +24,11 @@ $SPEC{'handle_cmd'} = {
 
 This subcommand is a shortcut for:
 
-    % lcpan mentions --type known-module --mentioned-module MOD
+    % lcpan mentions --type known-module --mentioned-module <module1> [module2] ...
+
+This searches PODs that mention either `module1`, `module2`, and so on. To
+search for PODs that mention *all* of the modules, see the
+`mentions-for-all-mods` subcommand.
 
 _
     args => {
@@ -61,7 +67,7 @@ App::lcpan::Cmd::mentions_for_mod - List POD mentions for module(s)
 
 =head1 VERSION
 
-This document describes version 1.067 of App::lcpan::Cmd::mentions_for_mod (from Perl distribution App-lcpan), released on 2021-06-03.
+This document describes version 1.068 of App::lcpan::Cmd::mentions_for_mod (from Perl distribution App-lcpan), released on 2021-06-05.
 
 =head1 FUNCTIONS
 
@@ -76,7 +82,11 @@ List POD mentions for module(s).
 
 This subcommand is a shortcut for:
 
- % lcpan mentions --type known-module --mentioned-module MOD
+ % lcpan mentions --type known-module --mentioned-module <module1> [module2] ...
+
+This searches PODs that mention either C<module1>, C<module2>, and so on. To
+search for PODs that mention I<all> of the modules, see the
+C<mentions-for-all-mods> subcommand.
 
 This function is not exported.
 
